summaryrefslogtreecommitdiffstats
path: root/korn/systemtray.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/systemtray.h')
-rw-r--r--korn/systemtray.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/korn/systemtray.h b/korn/systemtray.h
index 83daaeb3..6338ae57 100644
--- a/korn/systemtray.h
+++ b/korn/systemtray.h
@@ -31,13 +31,14 @@ class TQWidget;
*/
class SystemTray : public KSystemTray
{ Q_OBJECT
+ TQ_OBJECT
public:
/**
* This contructor gives all it parameters to its parents.
* @param parant The parent window
* @param name The name of the QObject's parents.
*/
- SystemTray( TQWidget * parent = 0, const char * name = 0 );
+ SystemTray( TQWidget * tqparent = 0, const char * name = 0 );
/**
* Empty destructor; does nothing at the moment
*/
@@ -47,12 +48,12 @@ protected:
/**
* Reimplementation because in the reimplementation of KSystray it popup's of restores.
* In this implemention, the action depends on the settings.
- * @param me An object which tqcontains the mousebutton which is pressed.
+ * @param me An object which contains the mousebutton which is pressed.
*/
virtual void mousePressEvent( TQMouseEvent* me );
signals:
- void mouseButtonPressed( Qt::ButtonState );
+ void mouseButtonPressed( TQt::ButtonState );
};
#endif //MK_SYSTEMTRAY_H
@@ -31,13 +31,14 @@ class TQWidget;
public:
/**
- * This contructor gives all it parameters to its parents.
- * @param parant The parent window
- * @param name The name of the QObject's parents.
+ * This contructor gives all it parameters to its tqparents.
+ * @param parant The tqparent window
+ * @param name The name of the TQObject's tqparents.
*/